@@ -154,7 +154,7 @@ static int DlgAlert_ShowDlg(const char *text)
 
 	i = SDLGui_DoDialog(alertdlg, NULL);
 
-	SDL_UpdateRect(surf, 0,0, 0,0);
+	scr_update(0,0, 0,0);
 	SDL_ShowCursor(bOldMouseVisibility);
 
 	return (i == DLGALERT_OK);
