@@ -38,7 +38,6 @@ static SDL_Surface *pSdlGuiScrn;            /* Pointer to the actual main SDL sc
 //static SDL_Surface *pSmallFontGfx = NULL;   /* The small font graphics */
 static SDL_Surface *pBigFontGfx = NULL;     /* The big font graphics */
 static SDL_Surface *pFontGfx = NULL;        /* The actual font graphics */
-static int current_object = 0;              /* Current selected object */
 static bool has_utf8;
 
 static inline int SDLGui_SetColors(SDL_Surface *surface, SDL_Color *colors,
@@ -461,50 +460,6 @@ static void SDLGui_DrawCheckBox(const SGOBJ *cdlg, int objnum)
 }
 
 
-/*-----------------------------------------------------------------------*/
-/**
- * Draw a scrollbar button.
- */
-static void SDLGui_DrawScrollbar(const SGOBJ *bdlg, int objnum)
-{
-	SDL_Rect rect;
-	int x, y, w, h;
-	Uint32 grey0 = SDL_MapRGB(pSdlGuiScrn->format,128,128,128);
-	Uint32 grey1 = SDL_MapRGB(pSdlGuiScrn->format,196,196,196);
-	Uint32 grey2 = SDL_MapRGB(pSdlGuiScrn->format, 64, 64, 64);
-
-	x = bdlg[objnum].x * sdlgui_fontwidth;
-	y = bdlg[objnum].y * sdlgui_fontheight + bdlg[objnum].h;
-
-	x += bdlg[0].x*sdlgui_fontwidth;   /* add mainbox absolute coordinates */
-	y += bdlg[0].y*sdlgui_fontheight;  /* add mainbox absolute coordinates */
-	
-	w = 1 * sdlgui_fontwidth;
-	h = bdlg[objnum].w;
-
-	/* Draw background: */
-	rect.x = x;
-	rect.y = y;
-	rect.w = w;
-	rect.h = h;
-	SDL_FillRect(pSdlGuiScrn, &rect, grey0);
-
-	/* Draw upper border: */
-	rect.x = x;
-	rect.y = y;
-	rect.w = w;
-	rect.h = 1;
-	SDL_FillRect(pSdlGuiScrn, &rect, grey1);
-
-	/* Draw bottom border: */
-	rect.x = x;
-	rect.y = y + h - 1;
-	rect.w = w;
-	rect.h = 1;
-	SDL_FillRect(pSdlGuiScrn, &rect, grey2);
-	
-}
-
 /*-----------------------------------------------------------------------*/
 /**
  *  Draw a dialog popup button object.
@@ -678,7 +633,7 @@ static void SDLGui_EditField(SGOBJ *dlg, int objnum)
 static void SDLGui_DrawUserObj(const SGOBJ *bdlg, int objnum)
 {
 	int x, y, w, h;
-	char (*userfun)(int x, int y, int w, int h);
+	void (*userfun)(int x, int y, int w, int h);
 
 	x = bdlg[objnum].x*sdlgui_fontwidth;
 	y = bdlg[objnum].y*sdlgui_fontheight;
@@ -729,9 +684,6 @@ void SDLGui_DrawDialog(const SGOBJ *dlg)
 		 case SGPOPUP:
 			SDLGui_DrawPopupButton(dlg, i);
 			break;
-		 case SGSCROLLBAR:
-			SDLGui_DrawScrollbar(dlg, i);
-			break;
 		 case SGUSER:
 			SDLGui_DrawUserObj(dlg, i);
 			break;
@@ -759,18 +711,8 @@ static int SDLGui_FindObj(const SGOBJ *dlg, int fx, int fy)
 	/* Now search for the object: */
 	for (i = len; i >= 0; i--)
 	{
-		/* clicked on a scrollbar ? */
-		if (dlg[i].type == SGSCROLLBAR) {
-			if (xpos >= dlg[0].x+dlg[i].x && xpos < dlg[0].x+dlg[i].x+1) {
-				ypos = dlg[i].y * sdlgui_fontheight + dlg[i].h + dlg[0].y * sdlgui_fontheight;
-				if (fy >= ypos && fy < ypos + dlg[i].w) {
-					ob = i;
-					break;
-				}
-			}
-		}
 		/* clicked on another object ? */
-		else if (xpos >= dlg[0].x+dlg[i].x && ypos >= dlg[0].y+dlg[i].y
+		if (xpos >= dlg[0].x+dlg[i].x && ypos >= dlg[0].y+dlg[i].y
 		    && xpos < dlg[0].x+dlg[i].x+dlg[i].w && ypos < dlg[0].y+dlg[i].y+dlg[i].h)
 		{
 			ob = i;
@@ -812,7 +754,7 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 	int obj=0;
 	int oldbutton=0;
 	int retbutton=0;
-	int i, j, b;
+	int i;
 	SDL_Event sdlEvent;
 	SDL_Rect rct;
 	Uint32 grey;
@@ -857,42 +799,6 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 	/* (Re-)draw the dialog */
 	SDLGui_DrawDialog(dlg);
 
-	/* Is the left mouse button still pressed? Yes -> Handle TOUCHEXIT objects here */
-	SDL_PumpEvents();
-	b = SDL_GetMouseState(&i, &j);
-
-	/* If current object is the scrollbar, and mouse is still down, we can scroll it */
-	/* also if the mouse pointer has left the scrollbar */
-	if (dlg[current_object].type == SGSCROLLBAR) {
-		if (b & SDL_BUTTON(1)) {
-			obj = current_object;
-			dlg[obj].state |= SG_MOUSEDOWN;
-			oldbutton = obj;
-			retbutton = obj;
-		}
-		else {
-			obj = current_object;
-			current_object = 0;
-			dlg[obj].state &= SG_MOUSEUP;
-			retbutton = obj;
-			oldbutton = obj;
-		}
-	}
-	else {
-		obj = SDLGui_FindObj(dlg, i, j);
-		current_object = obj;
-		if (obj > 0 && (dlg[obj].flags&SG_TOUCHEXIT) )
-		{
-			oldbutton = obj;
-			if (b & SDL_BUTTON(1))
-			{
-				dlg[obj].state |= SG_SELECTED;
-				retbutton = obj;
-			}
-		}
-	}
-
-
 	/* The main loop */
 	while (retbutton == 0 /*&& !bQuitProgram*/)
 	{
@@ -927,16 +833,6 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 						scr_update_rects(pSdlGuiScrn, 1, &rct);
 						oldbutton=obj;
 					}
-					if (dlg[obj].type==SGSCROLLBAR)
-					{
-						dlg[obj].state |= SG_MOUSEDOWN;
-						oldbutton=obj;
-					}
-					if ( dlg[obj].flags&SG_TOUCHEXIT )
-					{
-						dlg[obj].state |= SG_SELECTED;
-						retbutton = obj;
-					}
 				}
 				break;
 
@@ -955,12 +851,6 @@ int SDLGui_DoDialog(SGOBJ *dlg, SDL_Event *pEventOut)
 					switch (dlg[obj].type)
 					{
 					 case SGBUTTON:
-						if (oldbutton==obj)
-							retbutton=obj;
-						break;
-					 case SGSCROLLBAR:
- 						dlg[obj].state &= SG_MOUSEUP;
-
 						if (oldbutton==obj)
 							retbutton=obj;
 						break;
